@@ -7,8 +7,7 @@ from trytond.pool import PoolMeta
 __all__ = ['Carrier']
 
 
-class Carrier:
-    __metaclass__ = PoolMeta
+class Carrier(metaclass=PoolMeta):
     __name__ = 'carrier'
 
     shipping_service = fields.Selection([
